@@ -390,12 +390,23 @@ class AutoConnectStage(PipelineStage):
                 # *nix network stack won't detect a dropped connection until the client tries to
                 # send something, so it's very possible that we're disconnected but don't know
                 # it yet.
+                #
+                # However, we only want to do this for errors - NOT operations that were cancelled.
+                #
+                # QUESTION: Is this necessary as described above? E2E tests pass without this code.
+                # Is this that the tests don't handle this case, or that this isn't necessary?
 
                 @pipeline_thread.runs_on_pipeline_thread
                 def check_for_connection_failure(op, error):
-                    if error and not self.pipeline_root.connected:
+                    # QUESTION: Perhaps this should be checking for specific (connection related)
+                    # errors, rather than excluding certain ones?
+                    if (
+                        error
+                        and not isinstance(error, pipeline_exceptions.OperationCancelled)
+                        and not self.pipeline_root.connected
+                    ):
                         logger.debug(
-                            "{}({}): op failed with {} and we're not conencted.  Re-submitting.".format(
+                            "{}({}): op failed with {} and we're not connected.  Re-submitting.".format(
                                 self.name, op.name, error
                             )
                         )
@@ -981,6 +992,9 @@ class ReconnectStage(PipelineStage):
                 self._complete_waiting_connect_ops(
                     pipeline_exceptions.OperationCancelled("Explicit disconnect invoked")
                 )
+                # TODO: There is a bug here. If in a WAITING_TO_RECONNECT state, and an explicit
+                # Disconnect occurs, it is completed here rather than going all the way down. This
+                # means that any in-flight operations are NOT cancelled.
                 op.complete()
 
             else:
@@ -1008,34 +1022,48 @@ class ReconnectStage(PipelineStage):
                 )
             )
 
-            # Only retry connection if:
-            #   1) Pipeline is configured to do retry
-            #   2) The root has not already realized the connection is dropped
-            #   3) The pipeline is logically connected (i.e. it is SUPPOSED to be connected)
-            if (
-                self.pipeline_root.pipeline_configuration.connection_retry
-                and self.pipeline_root.connected
-                and self.state == ReconnectState.LOGICALLY_CONNECTED
-            ):
-                # When we get disconnected, we try to reconnect as soon as we can.  We don't want
-                # to reconnect right here because we're in a callback in the middle of being
-                # disconnected and we want things to "settle down" a bit before reconnecting.
-                #
-                # We also use a timer to reconnect here because the "reconnect timer expired"
-                # code path is well tested.  If we tried to immediately reconnect here, there
-                # would be an entire set of scenarios that would need to be tested for
-                # this case, and these tests would be identical to the "reconnect timer expired"
-                # tests. Likewise, if there were 2 reconnect code paths (one immediate and one
-                # delayed), then both those paths would need to be maintained as separate
-                # flows
-                self.state = ReconnectState.WAITING_TO_RECONNECT
-                self._start_reconnect_timer(0.01)
+            # EXPECTED DISCONNECTION (i.e. a DisconnectOperation was previously issued)
+            if self.state == ReconnectState.LOGICALLY_DISCONNECTED and self.pipeline_root.connected:
+                # ReconnectState will remain LOGICALLY_DISCONNECTED
+                # No reconnect timer will be created.
+                logger.debug(
+                    "{}({}): Not attempting to reconnect (User-initiated disconnect)".format(
+                        self.name, event.name
+                    )
+                )
 
+            # UNEXPECTED DISCONNECTION (i.e. Connection has been lost)
+            elif self.state == ReconnectState.LOGICALLY_CONNECTED and self.pipeline_root.connected:
+                if self.pipeline_root.pipeline_configuration.connection_retry:
+                    # When we get disconnected, we try to reconnect as soon as we can.  We don't want
+                    # to reconnect right here because we're in a callback in the middle of being
+                    # disconnected and we want things to "settle down" a bit before reconnecting.
+                    #
+                    # We also use a timer to reconnect here because the "reconnect timer expired"
+                    # code path is well tested.  If we tried to immediately reconnect here, there
+                    # would be an entire set of scenarios that would need to be tested for
+                    # this case, and these tests would be identical to the "reconnect timer expired"
+                    # tests. Likewise, if there were 2 reconnect code paths (one immediate and one
+                    # delayed), then both those paths would need to be maintained as separate
+                    # flows
+                    logger.debug("{}({}): Attempting to reconnect".format(self.name, event.name))
+                    self.state = ReconnectState.WAITING_TO_RECONNECT
+                    self._start_reconnect_timer(0.01)
+                else:
+                    logger.debug(
+                        "{}({}): Not attempting to reconnect (Reconnect disabled)".format(
+                            self.name, event.name
+                        )
+                    )
+                    self.state = ReconnectState.LOGICALLY_DISCONNECTED
+
+            # BAD STATE (this block should not be reached)
             else:
-                # If user manually disconnected, ReconnectState will be LOGICALLY_DISCONNECTED, and
-                # no reconnect timer will be created.
-                # If connection retry is not enabled, no reconnect timer will be created
-                pass
+                logger.warning(
+                    "{}: DisconnectEvent received while in unexpected state - {}, Connected: {}".format(
+                        self.name, self.state, self.pipeline_root.connected
+                    )
+                )
 
             self.send_event_up(event)
 
